Struct UiState
pub struct UiState(/* private fields */);Expand description
Current UI state.
Implementations
impl UiState
impl UiState
pub const IS_MAP_OPEN: UiState
pub const IS_COMPASS_TOP_RIGHT: UiState
pub const DOES_COMPASS_HAVE_ROTATION_ENABLED: UiState
pub const GAME_HAS_FOCUS: UiState
pub const IS_IN_COMPETITIVE_MODE: UiState
pub const TEXTBOX_HAS_FOCUS: UiState
pub const IS_IN_COMBAT: UiState
impl UiState
impl UiState
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<UiState>
pub const fn from_bits(bits: u32) -> Option<UiState>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> UiState
pub const fn from_bits_truncate(bits: u32) -> UiState
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> UiState
pub const fn from_bits_retain(bits: u32) -> UiState
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<UiState>
pub fn from_name(name: &str) -> Option<UiState>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: UiState) -> bool
pub const fn intersects(&self, other: UiState) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: UiState) -> bool
pub const fn contains(&self, other: UiState) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: UiState)
pub fn remove(&mut self, other: UiState)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: UiState, value: bool)
pub fn set(&mut self, other: UiState, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: UiState) -> UiState
pub const fn intersection(self, other: UiState) -> UiState
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: UiState) -> UiState
pub const fn union(self, other: UiState) -> UiState
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: UiState) -> UiState
pub const fn difference(self, other: UiState) -> UiState
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: UiState) -> UiState
pub const fn symmetric_difference(self, other: UiState) -> UiState
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> UiState
pub const fn complement(self) -> UiState
The bitwise negation (!) of the bits in self, truncating the result.
impl UiState
impl UiState
pub const fn iter(&self) -> Iter<UiState>
pub const fn iter(&self) -> Iter<UiState>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<UiState>
pub const fn iter_names(&self) -> IterNames<UiState>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.